<?php
namespace nulib\db\sqlite;

use nulib\db\_private\_migration;

class _sqliteMigration extends _migration {
  static function with($migration): self {
    if ($migration instanceof self) return $migration;
    else return new static($migration);
  }

  function setup(): void {
    $this->db->exec([
      "create table if not exists _migration",
      "cols" => [
        "channel" => "varchar not null",
        "key" => "varchar not null",
        "done" => "integer not null default 0",
      ],
    ]);
  }

  function beforeMigrate(string $key): bool {
    $db = $this->db;
    $migrated = $db->get([
      "select 1 from _migration",
      "where" => [
        "channel" => $this->channel,
        "key" => $key,
        "done" => 1,
      ],
    ]);
    if ($migrated) return false;
    $db->exec([
      "insert or replace into _migration",
      "values" => [
        "channel" => $this->channel,
        "key" => $key,
        "done" => 0,
      ],
    ]);
    return true;
  }

  function afterMigrate(string $key): void {
    $this->db->exec([
      "update _migration",
      "values" => [
        "done" => 1,
      ],
      "where" => [
        "channel" => $this->channel,
        "key" => $key,
      ],
    ]);
  }
}
